pub fn project_iteration_trace(
seed: u64,
telemetry: ChunkTelemetry,
decisions: Vec<Decision>,
) -> IterationTraceExpand description
Projects one decoded chunk and its decisions into the host-independent trace view.
pub fn project_iteration_trace(
seed: u64,
telemetry: ChunkTelemetry,
decisions: Vec<Decision>,
) -> IterationTraceProjects one decoded chunk and its decisions into the host-independent trace view.